@@ -15,6 +15,8 @@ from typing import (
     overload,
     Union,
     Literal,
+    get_origin,
+    get_args
 )
 from typing_extensions import TypedDict
 
@@ -27,11 +29,8 @@ from exa_py.utils import (
     format_exa_result,
     maybe_get_query,
 )
-from dotenv import load_dotenv
 import os
 
-load_dotenv()
-
 is_beta = os.getenv("IS_BETA") == "True"
 
 
@@ -133,22 +132,22 @@ FIND_SIMILAR_OPTIONS_TYPES = {
     "category": [str],
 }
 
+# the livecrawl options
+LIVECRAWL_OPTIONS = Literal["always", "fallback", "never"]
+
 CONTENTS_OPTIONS_TYPES = {
     "ids": [list],
     "text": [dict, bool],
     "highlights": [dict, bool],
     "summary": [dict, bool],
     "metadata": [dict, bool],
-    
+    "livecrawl_timeout": [int],
+    "livecrawl": [LIVECRAWL_OPTIONS],
+    "filter_empty_results": [bool],
 }
 
-# the livecrawl options
-LIVECRAWL_OPTIONS = Literal["always", "fallback", "never"]
-CONTENTS_OPTIONS_TYPES["livecrawl_timeout"] = [int]
-CONTENTS_OPTIONS_TYPES["livecrawl"] = [LIVECRAWL_OPTIONS]
-
-if is_beta:
-    CONTENTS_OPTIONS_TYPES["filter_empty_results"] = [bool]
+# FOR BETA OPTIONS
+# if is_beta:
 
 
 def validate_search_options(
@@ -166,11 +165,20 @@ def validate_search_options(
     for key, value in options.items():
         if key not in expected:
             raise ValueError(f"Invalid option: '{key}'")
-        if not any(isinstance(value, t) for t in expected[key]):
+        if value is None:
+            continue
+        expected_types = expected[key]
+        if not any(is_valid_type(value, t) for t in expected_types):
             raise ValueError(
-                f"Invalid type for option '{key}': Expected one of {expected[key]}, got {type(value)}"
+                f"Invalid value for option '{key}': {value}. Expected one of {expected_types}"
             )
 
+def is_valid_type(value, expected_type):
+    if get_origin(expected_type) is Literal:
+        return value in get_args(expected_type)
+    if isinstance(expected_type, type):
+        return isinstance(value, expected_type)
+    return False  # For any other case
 
 class TextContentsOptions(TypedDict, total=False):
     """A class representing the options that you can specify when requesting text
@@ -421,8 +429,8 @@ class SearchResponse(Generic[T]):
 
     results: List[T]
     autoprompt_string: Optional[str]
-    auto_date: Optional[str]
     resolved_search_type: Optional[str]
+    auto_date: Optional[str]
 
     def __str__(self):
         output = "\n\n".join(str(result) for result in self.results)
@@ -458,7 +466,7 @@ class Exa:
         self,
         api_key: Optional[str],
         base_url: str = "https://api.exa.ai",
-        user_agent: str = "exa-py 1.0.18",
+        user_agent: str = "exa-py 1.1.8",
     ):
         """Initialize the Exa client with the provided API key and optional base URL and user agent.
 
@@ -528,8 +536,8 @@ class Exa:
         return SearchResponse(
             [Result(**to_snake_case(result)) for result in data["results"]],
             data["autopromptString"] if "autopromptString" in data else None,
-            data["autoDate"] if "autoDate" in data else None,
             data["resolvedSearchType"] if "resolvedSearchType" in data else None,
+            data["autoDate"] if "autoDate" in data else None,
         )
 
     @overload
@@ -863,6 +871,7 @@ class Exa:
             [Result(**to_snake_case(result)) for result in data["results"]],
             data["autopromptString"] if "autopromptString" in data else None,
             data["resolvedSearchType"] if "resolvedSearchType" in data else None,
+            data["autoDate"] if "autoDate" in data else None,
         )
 
     def find_similar(
@@ -889,6 +898,7 @@ class Exa:
             [Result(**to_snake_case(result)) for result in data["results"]],
             data["autopromptString"] if "autopromptString" in data else None,
             data["resolvedSearchType"] if "resolvedSearchType" in data else None,
+            data["autoDate"] if "autoDate" in data else None,
         )
 
     @overload
@@ -1097,6 +1107,7 @@ class Exa:
             [Result(**to_snake_case(result)) for result in data["results"]],
             data["autopromptString"] if "autopromptString" in data else None,
             data["resolvedSearchType"] if "resolvedSearchType" in data else None,
+            data["autoDate"] if "autoDate" in data else None,
         )
 
     def wrap(self, client: OpenAI):
@@ -1160,10 +1171,6 @@ class Exa:
                 **openai_kwargs,
             }
 
-            if use_exa != "none":
-                assert "tools" not in create_kwargs, "Tool use is not supported with Exa"
-                create_kwargs["tool_choice"] = use_exa
-
             return self._create_with_tool(
                 create_fn=func,
                 messages=list(messages),
@@ -1217,8 +1224,6 @@ class Exa:
         exa_result = self.search_and_contents(query, **exa_kwargs)
         exa_str = format_exa_result(exa_result, max_len=max_len)
         new_messages = add_message_to_messages(completion, messages, exa_str)
-        # For now, don't allow recursive tool calls
-        create_kwargs["tool_choice"] = "none"
         completion = create_fn(messages=new_messages, **create_kwargs)
 
         exa_completion = ExaOpenAICompletion.from_completion(
